@@ -11,9 +11,11 @@ import java.lang.reflect.InvocationTargetException;
 import javax.swing.JDialog;
 
 import net.sf.openrocket.document.OpenRocketDocument;
+import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.rocketcomponent.ComponentChangeEvent;
 import net.sf.openrocket.rocketcomponent.ComponentChangeListener;
 import net.sf.openrocket.rocketcomponent.RocketComponent;
+import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.util.BugException;
 import net.sf.openrocket.util.GUIUtil;
 import net.sf.openrocket.util.Prefs;
@@ -41,7 +43,8 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 	private RocketComponentConfig configurator = null;
 	
 	private final Window parent;
-	
+	private static final Translator trans = Application.getTranslator();
+
 	private ComponentConfigDialog(Window parent, OpenRocketDocument document,
 			RocketComponent component) {
 		super(parent);
@@ -93,7 +96,8 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 		this.setContentPane(configurator);
 		configurator.updateFields();
 		
-		setTitle(component.getComponentName() + " configuration");
+		//// configuration
+		setTitle(trans.get("ComponentCfgDlg.configuration1") + " " + component.getComponentName() + " " + trans.get("ComponentCfgDlg.configuration"));
 		
 		//		Dimension pref = getPreferredSize();
 		//		Dimension real = getSize();
@@ -109,7 +113,7 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 				findDialogContentsConstructor(component);
 		if (c != null) {
 			try {
-				return (RocketComponentConfig) c.newInstance(component);
+				return c.newInstance(component);
 			} catch (InstantiationException e) {
 				throw new BugException("BUG in constructor reflection", e);
 			} catch (IllegalAccessException e) {
@@ -124,6 +128,34 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 		throw new BugException("Unable to find any configurator for " + component);
 	}
 	
+	
+	private void closeDialog() {
+		this.setVisible(false);
+		this.dispose();
+		this.configurator.invalidateModels();
+	}
+	
+	
+	@Override
+	public void componentChanged(ComponentChangeEvent e) {
+		if (e.isTreeChange() || e.isUndoChange()) {
+			
+			// Hide dialog in case of tree or undo change
+			dialog.closeDialog();
+			
+		} else {
+			/*
+			 * TODO: HIGH:  The line below has caused a NullPointerException (without null check)
+			 * How is this possible?  The null check was added to avoid this, but the
+			 * root cause should be analyzed.
+			 * [Openrocket-bugs] 2009-12-12 19:23:22 Automatic bug report for OpenRocket 0.9.5
+			 */
+			if (configurator != null)
+				configurator.updateFields();
+		}
+	}
+	
+	
 	/**
 	 * Finds the Constructor of the given component's config dialog panel in 
 	 * CONFIGDIALOGPACKAGE.
@@ -179,7 +211,8 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 		dialog = new ComponentConfigDialog(parent, document, component);
 		dialog.setVisible(true);
 		
-		document.addUndoPosition("Modify " + component.getComponentName());
+		////Modify
+		document.addUndoPosition(trans.get("ComponentCfgDlg.Modify") + " " + component.getComponentName());
 	}
 	
 	
@@ -192,8 +225,9 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 	 * Hides the configuration dialog.  May be used even if not currently visible.
 	 */
 	public static void hideDialog() {
-		if (dialog != null)
-			dialog.setVisible(false);
+		if (dialog != null) {
+			dialog.closeDialog();
+		}
 	}
 	
 	
@@ -225,23 +259,4 @@ public class ComponentConfigDialog extends JDialog implements ComponentChangeLis
 		return (dialog != null) && (dialog.isVisible());
 	}
 	
-	
-	public void componentChanged(ComponentChangeEvent e) {
-		if (e.isTreeChange() || e.isUndoChange()) {
-			
-			// Hide dialog in case of tree or undo change
-			dialog.setVisible(false);
-			
-		} else {
-			/*
-			 * TODO: HIGH:  The line below has caused a NullPointerException (without null check)
-			 * How is this possible?  The null check was added to avoid this, but the
-			 * root cause should be analyzed.
-			 * [Openrocket-bugs] 2009-12-12 19:23:22 Automatic bug report for OpenRocket 0.9.5
-			 */
-			if (configurator != null)
-				configurator.updateFields();
-		}
-	}
-	
 }
