@@ -25,6 +25,8 @@ import java.net.URL;
 import java.net.URLDecoder;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.LinkedList;
+import java.util.List;
 import java.util.concurrent.ExecutionException;
 
 import javax.swing.Action;
@@ -39,7 +41,6 @@ import javax.swing.JMenuItem;
 import javax.swing.JOptionPane;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
-import javax.swing.JSeparator;
 import javax.swing.JSplitPane;
 import javax.swing.JTabbedPane;
 import javax.swing.JTextField;
@@ -50,7 +51,6 @@ import javax.swing.SwingUtilities;
 import javax.swing.border.TitledBorder;
 import javax.swing.event.TreeSelectionEvent;
 import javax.swing.event.TreeSelectionListener;
-import javax.swing.filechooser.FileFilter;
 import javax.swing.tree.DefaultTreeSelectionModel;
 import javax.swing.tree.TreePath;
 import javax.swing.tree.TreeSelectionModel;
@@ -69,14 +69,20 @@ import net.sf.openrocket.gui.dialogs.AboutDialog;
 import net.sf.openrocket.gui.dialogs.BugReportDialog;
 import net.sf.openrocket.gui.dialogs.ComponentAnalysisDialog;
 import net.sf.openrocket.gui.dialogs.DebugLogDialog;
+import net.sf.openrocket.gui.dialogs.DetailDialog;
 import net.sf.openrocket.gui.dialogs.ExampleDesignDialog;
 import net.sf.openrocket.gui.dialogs.LicenseDialog;
 import net.sf.openrocket.gui.dialogs.MotorDatabaseLoadingDialog;
+import net.sf.openrocket.gui.dialogs.PrintDialog;
+import net.sf.openrocket.gui.dialogs.ScaleDialog;
 import net.sf.openrocket.gui.dialogs.SwingWorkerDialog;
 import net.sf.openrocket.gui.dialogs.WarningDialog;
+import net.sf.openrocket.gui.dialogs.optimization.GeneralOptimizationDialog;
 import net.sf.openrocket.gui.dialogs.preferences.PreferencesDialog;
 import net.sf.openrocket.gui.main.componenttree.ComponentTree;
+import net.sf.openrocket.gui.optimization.OptimizationTestDialog;
 import net.sf.openrocket.gui.scalefigure.RocketPanel;
+import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.logging.LogHelper;
 import net.sf.openrocket.rocketcomponent.ComponentChangeEvent;
 import net.sf.openrocket.rocketcomponent.ComponentChangeListener;
@@ -85,8 +91,11 @@ import net.sf.openrocket.rocketcomponent.RocketComponent;
 import net.sf.openrocket.rocketcomponent.Stage;
 import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.util.BugException;
+import net.sf.openrocket.util.FileHelper;
 import net.sf.openrocket.util.GUIUtil;
 import net.sf.openrocket.util.Icons;
+import net.sf.openrocket.util.MemoryManagement;
+import net.sf.openrocket.util.MemoryManagement.MemoryData;
 import net.sf.openrocket.util.OpenFileWorker;
 import net.sf.openrocket.util.Prefs;
 import net.sf.openrocket.util.Reflection;
@@ -103,21 +112,8 @@ public class BasicFrame extends JFrame {
 	
 	private static final RocketSaver ROCKET_SAVER = new OpenRocketSaver();
 	
-
-	// FileFilters for different types of rocket design files
-	private static final FileFilter ALL_DESIGNS_FILTER =
-			new SimpleFileFilter("All rocket designs (*.ork; *.rkt)",
-					".ork", ".ork.gz", ".rkt", ".rkt.gz");
+	private static final Translator trans = Application.getTranslator();
 	
-	private static final FileFilter OPENROCKET_DESIGN_FILTER =
-			new SimpleFileFilter("OpenRocket designs (*.ork)", ".ork", ".ork.gz");
-	
-	private static final FileFilter ROCKSIM_DESIGN_FILTER =
-			new SimpleFileFilter("RockSim designs (*.rkt)", ".rkt", ".rkt.gz");
-	
-
-
-
 	public static final int COMPONENT_TAB = 0;
 	public static final int SIMULATION_TAB = 1;
 	
@@ -172,6 +168,7 @@ public class BasicFrame extends JFrame {
 
 		// Set replaceable flag to false at first modification
 		rocket.addComponentChangeListener(new ComponentChangeListener() {
+			@Override
 			public void componentChanged(ComponentChangeEvent e) {
 				replaceable = false;
 				BasicFrame.this.rocket.removeComponentChangeListener(this);
@@ -206,8 +203,10 @@ public class BasicFrame extends JFrame {
 
 		// The top tabbed pane
 		tabbedPane = new JTabbedPane();
-		tabbedPane.addTab("Rocket design", null, designTab());
-		tabbedPane.addTab("Flight simulations", null, simulationPanel);
+		//// Rocket design
+		tabbedPane.addTab(trans.get("BasicFrame.tab.Rocketdesign"), null, designTab());
+		//// Flight simulations
+		tabbedPane.addTab(trans.get("BasicFrame.tab.Flightsim"), null, simulationPanel);
 		
 		vertical.setTopComponent(tabbedPane);
 		
@@ -225,6 +224,7 @@ public class BasicFrame extends JFrame {
 		
 
 		rocket.addComponentChangeListener(new ComponentChangeListener() {
+			@Override
 			public void componentChanged(ComponentChangeEvent e) {
 				setTitle();
 			}
@@ -314,6 +314,7 @@ public class BasicFrame extends JFrame {
 		
 		// Update dialog when selection is changed
 		componentSelectionModel.addTreeSelectionListener(new TreeSelectionListener() {
+			@Override
 			public void valueChanged(TreeSelectionEvent e) {
 				// Scroll tree to the selected item
 				TreePath path = componentSelectionModel.getSelectionPath();
@@ -366,7 +367,7 @@ public class BasicFrame extends JFrame {
 		scroll.setBorder(null);
 		scroll.setViewportBorder(null);
 		
-		TitledBorder border = new TitledBorder("Add new component");
+		TitledBorder border = new TitledBorder(trans.get("BasicFrame.title.Addnewcomp"));
 		border.setTitleFont(border.getTitleFont().deriveFont(Font.BOLD));
 		scroll.setBorder(border);
 		
@@ -379,6 +380,19 @@ public class BasicFrame extends JFrame {
 	
 	
 
+	/**
+	 * Return the currently selected rocket component, or <code>null</code> if none selected.
+	 */
+	private RocketComponent getSelectedComponent() {
+		TreePath path = componentSelectionModel.getSelectionPath();
+		if (path == null)
+			return null;
+		tree.scrollPathToVisible(path);
+		
+		return (RocketComponent) path.getLastPathComponent();
+	}
+	
+	
 	/**
 	 * Creates the menu for the window.
 	 */
@@ -388,17 +402,21 @@ public class BasicFrame extends JFrame {
 		JMenuItem item;
 		
 		////  File
-		menu = new JMenu("File");
+		menu = new JMenu(trans.get("main.menu.file"));
 		menu.setMnemonic(KeyEvent.VK_F);
-		menu.getAccessibleContext().setAccessibleDescription("File-handling related tasks");
+		//// File-handling related tasks
+		menu.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.file.desc"));
 		menubar.add(menu);
 		
-		item = new JMenuItem("New", KeyEvent.VK_N);
+		//// New 
+		item = new JMenuItem(trans.get("main.menu.file.new"), KeyEvent.VK_N);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_N, ActionEvent.CTRL_MASK));
 		item.setMnemonic(KeyEvent.VK_N);
-		item.getAccessibleContext().setAccessibleDescription("Create a new rocket design");
+		//// Create a new rocket design
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.file.new.desc"));
 		item.setIcon(Icons.FILE_NEW);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("New... selected");
 				newAction();
@@ -410,11 +428,14 @@ public class BasicFrame extends JFrame {
 		});
 		menu.add(item);
 		
-		item = new JMenuItem("Open...", KeyEvent.VK_O);
+		//// Open...
+		item = new JMenuItem(trans.get("main.menu.file.open"), KeyEvent.VK_O);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_O, ActionEvent.CTRL_MASK));
-		item.getAccessibleContext().setAccessibleDescription("Open a rocket design");
+		//// Open a rocket design
+		item.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.item.Openrocketdesign"));
 		item.setIcon(Icons.FILE_OPEN);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Open... selected");
 				openAction();
@@ -422,12 +443,15 @@ public class BasicFrame extends JFrame {
 		});
 		menu.add(item);
 		
-		item = new JMenuItem("Open example...");
-		item.getAccessibleContext().setAccessibleDescription("Open an example rocket design");
+		//// Open example...
+		item = new JMenuItem(trans.get("main.menu.file.openExample"));
+		//// Open an example rocket design
+		item.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.item.Openexamplerocketdesign"));
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_O,
 				ActionEvent.CTRL_MASK | ActionEvent.SHIFT_MASK));
 		item.setIcon(Icons.FILE_OPEN_EXAMPLE);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Open example... selected");
 				URL[] urls = ExampleDesignDialog.selectExampleDesigns(BasicFrame.this);
@@ -443,11 +467,14 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
-		item = new JMenuItem("Save", KeyEvent.VK_S);
+		//// Save
+		item = new JMenuItem(trans.get("main.menu.file.save"), KeyEvent.VK_S);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S, ActionEvent.CTRL_MASK));
-		item.getAccessibleContext().setAccessibleDescription("Save the current rocket design");
+		//// Save the current rocket design
+		item.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.item.SavecurRocketdesign"));
 		item.setIcon(Icons.FILE_SAVE);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Save selected");
 				saveAction();
@@ -455,13 +482,15 @@ public class BasicFrame extends JFrame {
 		});
 		menu.add(item);
 		
-		item = new JMenuItem("Save as...", KeyEvent.VK_A);
+		//// Save as...
+		item = new JMenuItem(trans.get("main.menu.file.saveAs"), KeyEvent.VK_A);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S,
 				ActionEvent.CTRL_MASK | ActionEvent.SHIFT_MASK));
-		item.getAccessibleContext().setAccessibleDescription("Save the current rocket design " +
-				"to a new file");
+		//// Save the current rocket design to a new file
+		item.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.item.SavecurRocketdesnewfile"));
 		item.setIcon(Icons.FILE_SAVE_AS);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Save as... selected");
 				saveAsAction();
@@ -469,14 +498,32 @@ public class BasicFrame extends JFrame {
 		});
 		menu.add(item);
 		
-		//		menu.addSeparator();
-		menu.add(new JSeparator());
+		//// Print...
+		item = new JMenuItem(trans.get("main.menu.file.print"), KeyEvent.VK_P);
+		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, ActionEvent.CTRL_MASK));
+		//// Print parts list and fin template
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.file.print.desc"));
+		item.setIcon(Icons.FILE_PRINT);
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				log.user("Print action selected");
+				printAction();
+			}
+		});
+		menu.add(item);
 		
-		item = new JMenuItem("Close", KeyEvent.VK_C);
+
+		menu.addSeparator();
+		
+		//// Close
+		item = new JMenuItem(trans.get("main.menu.file.close"), KeyEvent.VK_C);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_W, ActionEvent.CTRL_MASK));
-		item.getAccessibleContext().setAccessibleDescription("Close the current rocket design");
+		//// Close the current rocket design
+		item.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.item.Closedesign"));
 		item.setIcon(Icons.FILE_CLOSE);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Close selected");
 				closeAction();
@@ -486,11 +533,14 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
-		item = new JMenuItem("Quit", KeyEvent.VK_Q);
+		//// Quit
+		item = new JMenuItem(trans.get("main.menu.file.quit"), KeyEvent.VK_Q);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q, ActionEvent.CTRL_MASK));
-		item.getAccessibleContext().setAccessibleDescription("Quit the program");
+		//// Quit the program
+		item.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.item.Quitprogram"));
 		item.setIcon(Icons.FILE_QUIT);
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Quit selected");
 				quitAction();
@@ -501,9 +551,10 @@ public class BasicFrame extends JFrame {
 
 
 		////  Edit
-		menu = new JMenu("Edit");
+		menu = new JMenu(trans.get("main.menu.edit"));
 		menu.setMnemonic(KeyEvent.VK_E);
-		menu.getAccessibleContext().setAccessibleDescription("Rocket editing");
+		//// Rocket editing
+		menu.getAccessibleContext().setAccessibleDescription(trans.get("BasicFrame.menu.Rocketedt"));
 		menubar.add(menu);
 		
 
@@ -511,7 +562,8 @@ public class BasicFrame extends JFrame {
 		item = new JMenuItem(action);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Z, ActionEvent.CTRL_MASK));
 		item.setMnemonic(KeyEvent.VK_U);
-		item.getAccessibleContext().setAccessibleDescription("Undo the previous operation");
+		//// Undo the previous operation
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.edit.undo.desc"));
 		
 		menu.add(item);
 		
@@ -519,8 +571,8 @@ public class BasicFrame extends JFrame {
 		item = new JMenuItem(action);
 		item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Y, ActionEvent.CTRL_MASK));
 		item.setMnemonic(KeyEvent.VK_R);
-		item.getAccessibleContext().setAccessibleDescription("Redo the previously undone " +
-				"operation");
+		//// Redo the previously undone operation
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.edit.redo.desc"));
 		menu.add(item);
 		
 		menu.addSeparator();
@@ -540,14 +592,34 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
-		item = new JMenuItem("Preferences");
-		item.setIcon(Icons.PREFERENCES);
-		item.getAccessibleContext().setAccessibleDescription("Setup the application " +
-				"preferences");
+
+
+		item = new JMenuItem(trans.get("main.menu.edit.resize"));
+		item.setIcon(Icons.EDIT_SCALE);
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.edit.resize.desc"));
 		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				log.user("Scale... selected");
+				ScaleDialog dialog = new ScaleDialog(document, getSelectedComponent(), BasicFrame.this);
+				dialog.setVisible(true);
+				dialog.dispose();
+			}
+		});
+		menu.add(item);
+		
+
+
+		//// Preferences
+		item = new JMenuItem(trans.get("main.menu.edit.preferences"));
+		item.setIcon(Icons.PREFERENCES);
+		//// Setup the application preferences
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.edit.preferences.desc"));
+		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Preferences selected");
-				PreferencesDialog.showPreferences();
+				PreferencesDialog.showPreferences(BasicFrame.this);
 			}
 		});
 		menu.add(item);
@@ -556,15 +628,18 @@ public class BasicFrame extends JFrame {
 
 
 		////  Analyze
-		menu = new JMenu("Analyze");
+		menu = new JMenu(trans.get("main.menu.analyze"));
 		menu.setMnemonic(KeyEvent.VK_A);
-		menu.getAccessibleContext().setAccessibleDescription("Analyzing the rocket");
+		//// Analyzing the rocket
+		menu.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.analyze.desc"));
 		menubar.add(menu);
 		
-		item = new JMenuItem("Component analysis", KeyEvent.VK_C);
-		item.getAccessibleContext().setAccessibleDescription("Analyze the rocket components " +
-				"separately");
+		//// Component analysis
+		item = new JMenuItem(trans.get("main.menu.analyze.componentAnalysis"), KeyEvent.VK_C);
+		//// Analyze the rocket components separately
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.analyze.componentAnalysis.desc"));
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Component analysis selected");
 				ComponentAnalysisDialog.showDialog(rocketpanel);
@@ -583,16 +658,19 @@ public class BasicFrame extends JFrame {
 
 		////  Help
 		
-		menu = new JMenu("Help");
+		menu = new JMenu(trans.get("main.menu.help"));
 		menu.setMnemonic(KeyEvent.VK_H);
-		menu.getAccessibleContext().setAccessibleDescription("Information about OpenRocket");
+		//// Information about OpenRocket
+		menu.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.desc"));
 		menubar.add(menu);
 		
 
-
-		item = new JMenuItem("License", KeyEvent.VK_L);
-		item.getAccessibleContext().setAccessibleDescription("OpenRocket license information");
+		//// License
+		item = new JMenuItem(trans.get("main.menu.help.license"), KeyEvent.VK_L);
+		//// OpenRocket license information
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.license.desc"));
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("License selected");
 				new LicenseDialog(BasicFrame.this).setVisible(true);
@@ -602,10 +680,12 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
-		item = new JMenuItem("Bug report", KeyEvent.VK_B);
-		item.getAccessibleContext().setAccessibleDescription("Information about reporting " +
-				"bugs in OpenRocket");
+		//// Bug report
+		item = new JMenuItem(trans.get("main.menu.help.bugReport"), KeyEvent.VK_B);
+		//// Information about reporting bugs in OpenRocket
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.bugReport.desc"));
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Bug report selected");
 				BugReportDialog.showBugReportDialog(BasicFrame.this);
@@ -613,9 +693,12 @@ public class BasicFrame extends JFrame {
 		});
 		menu.add(item);
 		
-		item = new JMenuItem("Debug log");
-		item.getAccessibleContext().setAccessibleDescription("View the OpenRocket debug log");
+		//// Debug log
+		item = new JMenuItem(trans.get("main.menu.help.debugLog"));
+		//// View the OpenRocket debug log
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.debugLog.desc"));
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Debug log selected");
 				new DebugLogDialog(BasicFrame.this).setVisible(true);
@@ -625,9 +708,12 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
-		item = new JMenuItem("About", KeyEvent.VK_A);
-		item.getAccessibleContext().setAccessibleDescription("About OpenRocket");
+		//// About
+		item = new JMenuItem(trans.get("main.menu.help.about"), KeyEvent.VK_A);
+		//// About OpenRocket
+		item.getAccessibleContext().setAccessibleDescription(trans.get("main.menu.help.about.desc"));
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("About selected");
 				new AboutDialog(BasicFrame.this).setVisible(true);
@@ -639,17 +725,23 @@ public class BasicFrame extends JFrame {
 		this.setJMenuBar(menubar);
 	}
 	
-	
 	private JMenu makeDebugMenu() {
 		JMenu menu;
 		JMenuItem item;
 		
+		/*
+		 * This menu is intentionally left untranslated.
+		 */
+
 		////  Debug menu
 		menu = new JMenu("Debug");
+		//// OpenRocket debugging tasks
 		menu.getAccessibleContext().setAccessibleDescription("OpenRocket debugging tasks");
 		
+		//// What is this menu?
 		item = new JMenuItem("What is this menu?");
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("What is this menu? selected");
 				JOptionPane.showMessageDialog(BasicFrame.this,
@@ -666,6 +758,7 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
+		//// Create test rocket
 		item = new JMenuItem("Create test rocket");
 		item.addActionListener(new ActionListener() {
 			@Override
@@ -730,8 +823,85 @@ public class BasicFrame extends JFrame {
 		
 		menu.addSeparator();
 		
+
+		item = new JMenuItem("Memory statistics");
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				log.user("Memory statistics selected");
+				
+				// Get discarded but remaining objects (this also runs System.gc multiple times)
+				List<MemoryData> objects = MemoryManagement.getRemainingCollectableObjects();
+				StringBuilder sb = new StringBuilder();
+				sb.append("Objects that should have been garbage-collected but have not been:\n");
+				int count = 0;
+				for (MemoryData data : objects) {
+					Object o = data.getReference().get();
+					if (o == null)
+						continue;
+					sb.append("Age ").append(System.currentTimeMillis() - data.getRegistrationTime())
+							.append(" ms:  ").append(o).append('\n');
+					count++;
+					// Explicitly null the strong reference to avoid possibility of invisible references
+					o = null;
+				}
+				sb.append("Total: " + count);
+				
+				// Get basic memory stats
+				System.gc();
+				long max = Runtime.getRuntime().maxMemory();
+				long free = Runtime.getRuntime().freeMemory();
+				long used = max - free;
+				String[] stats = new String[4];
+				stats[0] = "Memory usage:";
+				stats[1] = String.format("   Max memory:  %.1f MB", max / 1024.0 / 1024.0);
+				stats[2] = String.format("   Used memory: %.1f MB (%.0f%%)", used / 1024.0 / 1024.0, 100.0 * used / max);
+				stats[3] = String.format("   Free memory: %.1f MB (%.0f%%)", free / 1024.0 / 1024.0, 100.0 * free / max);
+				
+
+				DetailDialog.showDetailedMessageDialog(BasicFrame.this, stats, sb.toString(),
+						"Memory statistics", JOptionPane.INFORMATION_MESSAGE);
+			}
+		});
+		menu.add(item);
+		
+		//// Exhaust memory
+		item = new JMenuItem("Exhaust memory");
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				log.user("Exhaust memory selected");
+				LinkedList<byte[]> data = new LinkedList<byte[]>();
+				int count = 0;
+				final int bytesPerArray = 10240;
+				try {
+					while (true) {
+						byte[] array = new byte[bytesPerArray];
+						for (int i = 0; i < bytesPerArray; i++) {
+							array[i] = (byte) i;
+						}
+						data.add(array);
+						count++;
+					}
+				} catch (OutOfMemoryError error) {
+					data = null;
+					long size = bytesPerArray * (long) count;
+					String s = String.format("OutOfMemory occurred after %d iterations (approx. %.1f MB consumed)",
+							count, size / 1024.0 / 1024.0);
+					log.debug(s, error);
+					JOptionPane.showMessageDialog(BasicFrame.this, s);
+				}
+			}
+		});
+		menu.add(item);
+		
+
+		menu.addSeparator();
+		
+		//// Exception here
 		item = new JMenuItem("Exception here");
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Exception here selected");
 				throw new RuntimeException("Testing exception from menu action listener");
@@ -741,6 +911,7 @@ public class BasicFrame extends JFrame {
 		
 		item = new JMenuItem("Exception from EDT");
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Exception from EDT selected");
 				SwingUtilities.invokeLater(new Runnable() {
@@ -756,26 +927,53 @@ public class BasicFrame extends JFrame {
 		
 		item = new JMenuItem("Exception from other thread");
 		item.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
 				log.user("Exception from other thread selected");
 				new Thread() {
 					@Override
 					public void run() {
-						throw new RuntimeException("Testing exception from " +
-								"newly created thread");
+						throw new RuntimeException("Testing exception from newly created thread");
 					}
 				}.start();
 			}
 		});
 		menu.add(item);
 		
+		item = new JMenuItem("OutOfMemoryError here");
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				log.user("OutOfMemoryError here selected");
+				throw new OutOfMemoryError("Testing OutOfMemoryError from menu action listener");
+			}
+		});
+		menu.add(item);
+		
 
+		item = new JMenuItem("General optimization test");
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				new GeneralOptimizationDialog(document, BasicFrame.this).setVisible(true);
+			}
+		});
+		menu.add(item);
+		
 
+		item = new JMenuItem("Optimization test");
+		item.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				new OptimizationTestDialog(BasicFrame.this, document).setVisible(true);
+			}
+		});
+		menu.add(item);
+		
 		return menu;
 	}
 	
 	
-
 	/**
 	 * Select the tab on the main pane.
 	 * 
@@ -790,10 +988,10 @@ public class BasicFrame extends JFrame {
 	private void openAction() {
 		JFileChooser chooser = new JFileChooser();
 		
-		chooser.addChoosableFileFilter(ALL_DESIGNS_FILTER);
-		chooser.addChoosableFileFilter(OPENROCKET_DESIGN_FILTER);
-		chooser.addChoosableFileFilter(ROCKSIM_DESIGN_FILTER);
-		chooser.setFileFilter(ALL_DESIGNS_FILTER);
+		chooser.addChoosableFileFilter(FileHelper.ALL_DESIGNS_FILTER);
+		chooser.addChoosableFileFilter(FileHelper.OPENROCKET_DESIGN_FILTER);
+		chooser.addChoosableFileFilter(FileHelper.ROCKSIM_DESIGN_FILTER);
+		chooser.setFileFilter(FileHelper.ALL_DESIGNS_FILTER);
 		
 		chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
 		chooser.setMultiSelectionEnabled(true);
@@ -982,10 +1180,13 @@ public class BasicFrame extends JFrame {
 			log.info("Warnings while reading file: " + warnings);
 			WarningDialog.showWarnings(parent,
 					new Object[] {
-							"The following problems were encountered while opening " + filename + ".",
-							"Some design features may not have been loaded correctly."
+							//// The following problems were encountered while opening
+							trans.get("BasicFrame.WarningDialog.txt1") + " " + filename + ".",
+							//// Some design features may not have been loaded correctly.
+							trans.get("BasicFrame.WarningDialog.txt2")
 					},
-					"Warnings while opening file", warnings);
+					//// Warnings while opening file
+					trans.get("BasicFrame.WarningDialog.title"), warnings);
 		}
 		
 
@@ -1014,7 +1215,7 @@ public class BasicFrame extends JFrame {
 		log.info("Saving document to " + file);
 		
 		// Saving RockSim designs is not supported
-		if (ROCKSIM_DESIGN_FILTER.accept(file)) {
+		if (FileHelper.ROCKSIM_DESIGN_FILTER.accept(file)) {
 			file = new File(file.getAbsolutePath().replaceAll(".[rR][kK][tT](.[gG][zZ])?$",
 					".ork"));
 			
@@ -1042,7 +1243,7 @@ public class BasicFrame extends JFrame {
 		StorageOptionChooser storageChooser =
 				new StorageOptionChooser(document, document.getDefaultStorageOptions());
 		JFileChooser chooser = new JFileChooser();
-		chooser.setFileFilter(OPENROCKET_DESIGN_FILTER);
+		chooser.setFileFilter(FileHelper.OPENROCKET_DESIGN_FILTER);
 		chooser.setCurrentDirectory(Prefs.getDefaultDirectory());
 		chooser.setAccessory(storageChooser);
 		if (document.getFile() != null)
@@ -1063,22 +1264,9 @@ public class BasicFrame extends JFrame {
 		Prefs.setDefaultDirectory(chooser.getCurrentDirectory());
 		storageChooser.storeOptions(document.getDefaultStorageOptions());
 		
-		if (file.getName().indexOf('.') < 0) {
-			log.debug("File name does not contain extension, adding .ork");
-			String name = file.getAbsolutePath();
-			name = name + ".ork";
-			file = new File(name);
-		}
-		
-		if (file.exists()) {
-			log.info("File " + file + " exists, confirming overwrite from user");
-			int result = JOptionPane.showConfirmDialog(this,
-					"File '" + file.getName() + "' exists.  Do you want to overwrite it?",
-					"File exists", JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE);
-			if (result != JOptionPane.YES_OPTION) {
-				log.user("User decided not to overwrite the file");
-				return false;
-			}
+		file = FileHelper.ensureExtension(file, "ork");
+		if (!FileHelper.confirmWrite(file, this)) {
+			return false;
 		}
 		
 		return saveAs(file);
@@ -1139,9 +1327,10 @@ public class BasicFrame extends JFrame {
 			log.info("Confirming whether to save the design");
 			ComponentConfigDialog.hideDialog();
 			int result = JOptionPane.showConfirmDialog(this,
-					"Design '" + rocket.getName() + "' has not been saved.  " +
-							"Do you want to save it?",
-					"Design not saved", JOptionPane.YES_NO_CANCEL_OPTION,
+					trans.get("BasicFrame.dlg.lbl1") + rocket.getName() +
+							trans.get("BasicFrame.dlg.lbl2") + "  " +
+							trans.get("BasicFrame.dlg.lbl3"),
+					trans.get("BasicFrame.dlg.title"), JOptionPane.YES_NO_CANCEL_OPTION,
 					JOptionPane.QUESTION_MESSAGE);
 			if (result == JOptionPane.YES_OPTION) {
 				// Save
@@ -1177,6 +1366,20 @@ public class BasicFrame extends JFrame {
 	
 	
 
+	/**
+	 * 
+	 */
+	public void printAction() {
+		if (!Prefs.getBoolean("printing.experimental.communicated", false)) {
+			log.info("Showing printing is experimental warning to the user");
+			JOptionPane.showMessageDialog(this, "Printing is an currently an experimental feature " +
+					"and might not fully work on all platforms",
+					"Experimental feature", JOptionPane.WARNING_MESSAGE);
+			Prefs.putBoolean("printing.experimental.communicated", true);
+		}
+		new PrintDialog(this, document).setVisible(true);
+	}
+	
 	/**
 	 * Open a new design window with a basic rocket+stage.
 	 */
@@ -1185,7 +1388,8 @@ public class BasicFrame extends JFrame {
 		
 		Rocket rocket = new Rocket();
 		Stage stage = new Stage();
-		stage.setName("Sustainer");
+		//// Sustainer
+		stage.setName(trans.get("BasicFrame.StageName.Sustainer"));
 		rocket.addChild(stage);
 		OpenRocketDocument doc = new OpenRocketDocument(rocket);
 		doc.setSaved(true);
