@@ -1,35 +1,6 @@
 package net.sf.openrocket.gui.scalefigure;
 
 
-import java.awt.Dimension;
-import java.awt.Font;
-import java.awt.Point;
-import java.awt.event.ActionEvent;
-import java.awt.event.InputEvent;
-import java.awt.event.MouseEvent;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.List;
-import java.util.concurrent.Executor;
-import java.util.concurrent.Executors;
-import java.util.concurrent.ThreadFactory;
-
-import javax.swing.AbstractAction;
-import javax.swing.Action;
-import javax.swing.JComboBox;
-import javax.swing.JLabel;
-import javax.swing.JPanel;
-import javax.swing.JSlider;
-import javax.swing.JToggleButton;
-import javax.swing.JViewport;
-import javax.swing.SwingUtilities;
-import javax.swing.event.ChangeEvent;
-import javax.swing.event.ChangeListener;
-import javax.swing.event.TreeSelectionEvent;
-import javax.swing.event.TreeSelectionListener;
-import javax.swing.tree.TreePath;
-import javax.swing.tree.TreeSelectionModel;
-
 import net.miginfocom.swing.MigLayout;
 import net.sf.openrocket.aerodynamics.AerodynamicCalculator;
 import net.sf.openrocket.aerodynamics.BarrowmanCalculator;
@@ -49,6 +20,7 @@ import net.sf.openrocket.gui.figureelements.Caret;
 import net.sf.openrocket.gui.figureelements.RocketInfo;
 import net.sf.openrocket.gui.main.SimulationWorker;
 import net.sf.openrocket.gui.main.componenttree.ComponentTreeModel;
+import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.masscalc.BasicMassCalculator;
 import net.sf.openrocket.masscalc.MassCalculator;
 import net.sf.openrocket.masscalc.MassCalculator.MassCalcType;
@@ -60,6 +32,7 @@ import net.sf.openrocket.simulation.FlightData;
 import net.sf.openrocket.simulation.listeners.SimulationListener;
 import net.sf.openrocket.simulation.listeners.system.ApogeeEndListener;
 import net.sf.openrocket.simulation.listeners.system.InterruptListener;
+import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.unit.UnitGroup;
 import net.sf.openrocket.util.ChangeSource;
 import net.sf.openrocket.util.Chars;
@@ -67,6 +40,34 @@ import net.sf.openrocket.util.Coordinate;
 import net.sf.openrocket.util.MathUtil;
 import net.sf.openrocket.util.Prefs;
 
+import javax.swing.AbstractAction;
+import javax.swing.Action;
+import javax.swing.JComboBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JSlider;
+import javax.swing.JToggleButton;
+import javax.swing.JViewport;
+import javax.swing.SwingUtilities;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
+import javax.swing.event.TreeSelectionEvent;
+import javax.swing.event.TreeSelectionListener;
+import javax.swing.tree.TreePath;
+import javax.swing.tree.TreeSelectionModel;
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.Point;
+import java.awt.event.ActionEvent;
+import java.awt.event.InputEvent;
+import java.awt.event.MouseEvent;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.List;
+import java.util.concurrent.Executor;
+import java.util.concurrent.Executors;
+import java.util.concurrent.ThreadFactory;
+
 /**
  * A JPanel that contains a RocketFigure and buttons to manipulate the figure. 
  * 
@@ -74,6 +75,7 @@ import net.sf.openrocket.util.Prefs;
  */
 public class RocketPanel extends JPanel implements TreeSelectionListener, ChangeSource {
 	
+	private static final Translator trans = Application.getTranslator();
 	private final RocketFigure figure;
 	private final ScaleScrollPane scrollPane;
 	
@@ -106,8 +108,8 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 	
 
 	private SimulationWorker backgroundSimulationWorker = null;
+	private boolean dirty = false;
 	
-
 	private List<ChangeListener> listeners = new ArrayList<ChangeListener>();
 	
 
@@ -180,14 +182,18 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 		
 		// Side/back buttons
 		FigureTypeAction action = new FigureTypeAction(RocketFigure.TYPE_SIDE);
-		action.putValue(Action.NAME, "Side view");
-		action.putValue(Action.SHORT_DESCRIPTION, "Side view");
+		//// Side view
+		action.putValue(Action.NAME, trans.get("RocketPanel.FigTypeAct.Sideview"));
+		//// Side view
+		action.putValue(Action.SHORT_DESCRIPTION, trans.get("RocketPanel.FigTypeAct.ttip.Sideview"));
 		JToggleButton toggle = new JToggleButton(action);
 		add(toggle, "spanx, split");
 		
 		action = new FigureTypeAction(RocketFigure.TYPE_BACK);
-		action.putValue(Action.NAME, "Back view");
-		action.putValue(Action.SHORT_DESCRIPTION, "Rear view");
+		//// Back view
+		action.putValue(Action.NAME, trans.get("RocketPanel.FigTypeAct.Backview"));
+		//// Back view
+		action.putValue(Action.SHORT_DESCRIPTION, trans.get("RocketPanel.FigTypeAct.ttip.Backview"));
 		toggle = new JToggleButton(action);
 		add(toggle, "gap rel");
 		
@@ -205,8 +211,8 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 
 
 		// Motor configuration selector
-		
-		JLabel label = new JLabel("Motor configuration:");
+		//// Motor configuration:
+		JLabel label = new JLabel(trans.get("RocketPanel.lbl.Motorcfg"));
 		label.setHorizontalAlignment(JLabel.RIGHT);
 		add(label, "growx, right");
 		add(new JComboBox(new MotorConfigurationModel(configuration)), "wrap");
@@ -235,12 +241,9 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 		add(new BasicSlider(theta.getSliderModel(0, 2 * Math.PI), JSlider.VERTICAL, true),
 				"ax 50%, wrap, width " + (d.width + 6) + "px:null:null, growy");
 		
-
-		infoMessage = new JLabel("<html>" +
-				"Click to select &nbsp;&nbsp; " +
-				"Shift+click to select other &nbsp;&nbsp; " +
-				"Double-click to edit &nbsp;&nbsp; " +
-				"Click+drag to move");
+		
+		//// <html>Click to select &nbsp;&nbsp; Shift+click to select other &nbsp;&nbsp; Double-click to edit &nbsp;&nbsp; Click+drag to move
+		infoMessage = new JLabel(trans.get("RocketPanel.lbl.infoMessage"));
 		infoMessage.setFont(new Font("Sans Serif", Font.PLAIN, 9));
 		add(infoMessage, "skip, span, gapleft 25, wrap");
 		
@@ -260,8 +263,35 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 	public Configuration getConfiguration() {
 		return configuration;
 	}
-	
-	public void setSelectionModel(TreeSelectionModel m) {
+
+    /**
+     * Get the center of pressure figure element.
+     * 
+     * @return center of pressure info
+     */
+    public Caret getExtraCP () {
+        return extraCP;
+    }
+
+    /**
+     * Get the center of gravity figure element.
+     * 
+     * @return center of gravity info
+     */
+    public Caret getExtraCG () {
+        return extraCG;
+    }
+
+    /**
+     * Get the extra text figure element.
+     * 
+     * @return extra text that contains info about the rocket design
+     */
+    public RocketInfo getExtraText () {
+        return extraText;
+    }
+
+    public void setSelectionModel(TreeSelectionModel m) {
 		if (selectionModel != null) {
 			selectionModel.removeTreeSelectionListener(this);
 		}
@@ -608,7 +638,7 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 		@Override
 		protected void simulationDone() {
 			// Do nothing if cancelled
-			if (isCancelled() || backgroundSimulationWorker != this) // Double-check
+			if (isCancelled() || backgroundSimulationWorker != this)
 				return;
 			
 			backgroundSimulationWorker = null;
@@ -658,6 +688,7 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 	 * Updates the selection in the FigureParameters and repaints the figure.  
 	 * Ignores the event itself.
 	 */
+	@Override
 	public void valueChanged(TreeSelectionEvent e) {
 		TreePath[] paths = selectionModel.getSelectionPaths();
 		if (paths == null) {
@@ -688,6 +719,7 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 			figure.addChangeListener(this);
 		}
 		
+		@Override
 		public void actionPerformed(ActionEvent e) {
 			boolean state = (Boolean) getValue(Action.SELECTED_KEY);
 			if (state == true) {
@@ -698,6 +730,7 @@ public class RocketPanel extends JPanel implements TreeSelectionListener, Change
 			stateChanged(null);
 		}
 		
+		@Override
 		public void stateChanged(ChangeEvent e) {
 			putValue(Action.SELECTED_KEY, figure.getType() == type);
 		}
