@@ -1,8 +1,12 @@
 package net.sf.openrocket.rocketcomponent;
 
+import net.sf.openrocket.l10n.Translator;
+import net.sf.openrocket.startup.Application;
+
 
 public class Bulkhead extends RadiusRingComponent {
-	
+	private static final Translator trans = Application.getTranslator();
+
 	public Bulkhead() {
 		setOuterRadiusAutomatic(true);
 		setLength(0.002);
@@ -25,7 +29,8 @@ public class Bulkhead extends RadiusRingComponent {
 	
 	@Override
 	public String getComponentName() {
-		return "Bulkhead";
+		//// Bulkhead
+		return trans.get("Bulkhead.Bulkhead");
 	}
 	
 	@Override
