@@ -1,6 +1,5 @@
 package net.sf.openrocket.rocketcomponent;
 
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -12,7 +11,12 @@ import java.util.UUID;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.EventListenerList;
 
+import net.sf.openrocket.gui.main.ExceptionHandler;
+import net.sf.openrocket.l10n.Translator;
+import net.sf.openrocket.logging.LogHelper;
 import net.sf.openrocket.motor.Motor;
+import net.sf.openrocket.startup.Application;
+import net.sf.openrocket.util.ArrayList;
 import net.sf.openrocket.util.Chars;
 import net.sf.openrocket.util.Coordinate;
 import net.sf.openrocket.util.MathUtil;
@@ -25,14 +29,15 @@ import net.sf.openrocket.util.UniqueID;
  * (eg. the rocket listener lists) and the methods defined in RocketComponent call these.
  * It also defines some other methods that concern the whole rocket, and helper methods
  * that keep information about the program state.
- * 
+ *
  * @author Sampo Niskanen <sampo.niskanen@iki.fi>
  */
 
 public class Rocket extends RocketComponent {
-	public static final double DEFAULT_REFERENCE_LENGTH = 0.01;
+	private static final LogHelper log = Application.getLogger();
+	private static final Translator trans = Application.getTranslator();
 	
-	private static final boolean DEBUG_LISTENERS = false;
+	public static final double DEFAULT_REFERENCE_LENGTH = 0.01;
 	
 
 	/**
@@ -123,7 +128,7 @@ public class Rocket extends RocketComponent {
 
 	/**
 	 * Return the number of stages in this rocket.
-	 * 
+	 *
 	 * @return   the number of stages in this rocket.
 	 */
 	public int getStageCount() {
@@ -132,23 +137,22 @@ public class Rocket extends RocketComponent {
 	}
 	
 	
-
 	/**
 	 * Return the non-negative modification ID of this rocket.  The ID is changed
-	 * every time any change occurs in the rocket.  This can be used to check 
+	 * every time any change occurs in the rocket.  This can be used to check
 	 * whether it is necessary to void cached data in cases where listeners can not
 	 * or should not be used.
 	 * <p>
 	 * Three other modification IDs are also available, {@link #getMassModID()},
-	 * {@link #getAerodynamicModID()} {@link #getTreeModID()}, which change every time 
-	 * a mass change, aerodynamic change, or tree change occur.  Even though the values 
-	 * of the different modification ID's may be equal, they should be treated totally 
+	 * {@link #getAerodynamicModID()} {@link #getTreeModID()}, which change every time
+	 * a mass change, aerodynamic change, or tree change occur.  Even though the values
+	 * of the different modification ID's may be equal, they should be treated totally
 	 * separate.
 	 * <p>
 	 * Note that undo events restore the modification IDs that were in use at the
 	 * corresponding undo level.  Subsequent modifications, however, produce modIDs
 	 * distinct from those already used.
-	 * 
+	 *
 	 * @return   a unique ID number for this modification state.
 	 */
 	public int getModID() {
@@ -158,7 +162,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Return the non-negative mass modification ID of this rocket.  See
 	 * {@link #getModID()} for details.
-	 * 
+	 *
 	 * @return   a unique ID number for this mass-modification state.
 	 */
 	public int getMassModID() {
@@ -168,7 +172,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Return the non-negative aerodynamic modification ID of this rocket.  See
 	 * {@link #getModID()} for details.
-	 * 
+	 *
 	 * @return   a unique ID number for this aerodynamic-modification state.
 	 */
 	public int getAerodynamicModID() {
@@ -178,7 +182,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Return the non-negative tree modification ID of this rocket.  See
 	 * {@link #getModID()} for details.
-	 * 
+	 *
 	 * @return   a unique ID number for this tree-modification state.
 	 */
 	public int getTreeModID() {
@@ -188,7 +192,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Return the non-negative functional modificationID of this rocket.
 	 * This changes every time a functional change occurs.
-	 * 
+	 *
 	 * @return	a unique ID number for this functional modification state.
 	 */
 	public int getFunctionalModID() {
@@ -234,7 +238,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Set whether the rocket has a perfect finish.  This will affect whether the
 	 * boundary layer is assumed to be fully turbulent or not.
-	 * 
+	 *
 	 * @param perfectFinish		whether the finish is perfect.
 	 */
 	public void setPerfectFinish(boolean perfectFinish) {
@@ -248,7 +252,7 @@ public class Rocket extends RocketComponent {
 
 	/**
 	 * Get whether the rocket has a perfect finish.
-	 * 
+	 *
 	 * @return the perfectFinish
 	 */
 	public boolean isPerfectFinish() {
@@ -263,11 +267,11 @@ public class Rocket extends RocketComponent {
 	 * Make a deep copy of the Rocket structure.  This method is exposed as public to allow
 	 * for undo/redo system functionality.
 	 */
-	@Override
 	@SuppressWarnings("unchecked")
+	@Override
 	public Rocket copyWithOriginalID() {
 		Rocket copy = (Rocket) super.copyWithOriginalID();
-		copy.motorConfigurationIDs = (ArrayList<String>) this.motorConfigurationIDs.clone();
+		copy.motorConfigurationIDs = this.motorConfigurationIDs.clone();
 		copy.motorConfigurationNames =
 				(HashMap<String, String>) this.motorConfigurationNames.clone();
 		copy.resetListeners();
@@ -287,15 +291,17 @@ public class Rocket extends RocketComponent {
 	 */
 	@SuppressWarnings("unchecked")
 	public void loadFrom(Rocket r) {
-		super.copyFrom(r);
+		
+		// Store list of components to invalidate after event has been fired
+		List<RocketComponent> toInvalidate = this.copyFrom(r);
 		
 		int type = ComponentChangeEvent.UNDO_CHANGE | ComponentChangeEvent.NONFUNCTIONAL_CHANGE;
 		if (this.massModID != r.massModID)
 			type |= ComponentChangeEvent.MASS_CHANGE;
 		if (this.aeroModID != r.aeroModID)
 			type |= ComponentChangeEvent.AERODYNAMIC_CHANGE;
-		if (this.treeModID != r.treeModID)
-			type |= ComponentChangeEvent.TREE_CHANGE;
+		// Loading a rocket is always a tree change since the component objects change
+		type |= ComponentChangeEvent.TREE_CHANGE;
 		
 		this.modID = r.modID;
 		this.massModID = r.massModID;
@@ -305,7 +311,7 @@ public class Rocket extends RocketComponent {
 		this.refType = r.refType;
 		this.customReferenceLength = r.customReferenceLength;
 		
-		this.motorConfigurationIDs = (ArrayList<String>) r.motorConfigurationIDs.clone();
+		this.motorConfigurationIDs = r.motorConfigurationIDs.clone();
 		this.motorConfigurationNames =
 				(HashMap<String, String>) r.motorConfigurationNames.clone();
 		this.perfectFinish = r.perfectFinish;
@@ -314,7 +320,14 @@ public class Rocket extends RocketComponent {
 		if (!this.motorConfigurationIDs.contains(id))
 			defaultConfiguration.setMotorConfigurationID(null);
 		
+		this.checkComponentStructure();
+		
 		fireComponentChangeEvent(type);
+		
+		// Invalidate obsolete components after event
+		for (RocketComponent c : toInvalidate) {
+			c.invalidate();
+		}
 	}
 	
 	
@@ -343,17 +356,15 @@ public class Rocket extends RocketComponent {
 	public void addComponentChangeListener(ComponentChangeListener l) {
 		checkState();
 		listenerList.add(ComponentChangeListener.class, l);
-		if (DEBUG_LISTENERS)
-			System.out.println(this + ": Added listner (now " + listenerList.getListenerCount() +
-					" listeners): " + l);
+		log.verbose("Added ComponentChangeListener " + l + ", current number of listeners is " +
+				listenerList.getListenerCount());
 	}
 	
 	@Override
 	public void removeComponentChangeListener(ComponentChangeListener l) {
 		listenerList.remove(ComponentChangeListener.class, l);
-		if (DEBUG_LISTENERS)
-			System.out.println(this + ": Removed listner (now " + listenerList.getListenerCount() +
-					" listeners): " + l);
+		log.verbose("Removed ComponentChangeListener " + l + ", current number of listeners is " +
+				listenerList.getListenerCount());
 	}
 	
 	
@@ -361,60 +372,63 @@ public class Rocket extends RocketComponent {
 	public void addChangeListener(ChangeListener l) {
 		checkState();
 		listenerList.add(ChangeListener.class, l);
-		if (DEBUG_LISTENERS)
-			System.out.println(this + ": Added listner (now " + listenerList.getListenerCount() +
-					" listeners): " + l);
+		log.verbose("Added ChangeListener " + l + ", current number of listeners is " +
+				listenerList.getListenerCount());
 	}
 	
 	@Override
 	public void removeChangeListener(ChangeListener l) {
 		listenerList.remove(ChangeListener.class, l);
-		if (DEBUG_LISTENERS)
-			System.out.println(this + ": Removed listner (now " + listenerList.getListenerCount() +
-					" listeners): " + l);
+		log.verbose("Removed ChangeListener " + l + ", current number of listeners is " +
+				listenerList.getListenerCount());
 	}
 	
 	
 	@Override
 	protected void fireComponentChangeEvent(ComponentChangeEvent e) {
-		checkState();
-		
-		// Update modification ID's only for normal (not undo/redo) events
-		if (!e.isUndoChange()) {
-			modID = UniqueID.next();
-			if (e.isMassChange())
-				massModID = modID;
-			if (e.isAerodynamicChange())
-				aeroModID = modID;
-			if (e.isTreeChange())
-				treeModID = modID;
-			if (e.getType() != ComponentChangeEvent.NONFUNCTIONAL_CHANGE)
-				functionalModID = modID;
-		}
-		
-		if (DEBUG_LISTENERS)
-			System.out.println("FIRING " + e);
-		
-		// Check whether frozen
-		if (freezeList != null) {
-			freezeList.add(e);
-			return;
-		}
-		
-		// Notify all components first
-		Iterator<RocketComponent> iterator = this.deepIterator(true);
-		while (iterator.hasNext()) {
-			iterator.next().componentChanged(e);
-		}
-		
-		// Notify all listeners
-		Object[] listeners = listenerList.getListenerList();
-		for (int i = listeners.length - 2; i >= 0; i -= 2) {
-			if (listeners[i] == ComponentChangeListener.class) {
-				((ComponentChangeListener) listeners[i + 1]).componentChanged(e);
-			} else if (listeners[i] == ChangeListener.class) {
-				((ChangeListener) listeners[i + 1]).stateChanged(e);
+		mutex.lock("fireComponentChangeEvent");
+		try {
+			checkState();
+			
+			// Update modification ID's only for normal (not undo/redo) events
+			if (!e.isUndoChange()) {
+				modID = UniqueID.next();
+				if (e.isMassChange())
+					massModID = modID;
+				if (e.isAerodynamicChange())
+					aeroModID = modID;
+				if (e.isTreeChange())
+					treeModID = modID;
+				if (e.getType() != ComponentChangeEvent.NONFUNCTIONAL_CHANGE)
+					functionalModID = modID;
 			}
+			
+			// Check whether frozen
+			if (freezeList != null) {
+				log.debug("Rocket is in frozen state, adding event " + e + " info freeze list");
+				freezeList.add(e);
+				return;
+			}
+			
+			log.debug("Firing rocket change event " + e);
+			
+			// Notify all components first
+			Iterator<RocketComponent> iterator = this.iterator(true);
+			while (iterator.hasNext()) {
+				iterator.next().componentChanged(e);
+			}
+			
+			// Notify all listeners
+			Object[] listeners = listenerList.getListenerList();
+			for (int i = listeners.length - 2; i >= 0; i -= 2) {
+				if (listeners[i] == ComponentChangeListener.class) {
+					((ComponentChangeListener) listeners[i + 1]).componentChanged(e);
+				} else if (listeners[i] == ChangeListener.class) {
+					((ChangeListener) listeners[i + 1]).stateChanged(e);
+				}
+			}
+		} finally {
+			mutex.unlock("fireComponentChangeEvent");
 		}
 	}
 	
@@ -423,7 +437,7 @@ public class Rocket extends RocketComponent {
 	 * Freezes the rocket structure from firing any events.  This may be performed to
 	 * combine several actions on the structure into a single large action.
 	 * <code>thaw()</code> must always be called afterwards.
-	 * 
+	 *
 	 * NOTE:  Always use a try/finally to ensure <code>thaw()</code> is called:
 	 * <pre>
 	 *     Rocket r = c.getRocket();
@@ -434,13 +448,17 @@ public class Rocket extends RocketComponent {
 	 *         r.thaw();
 	 *     }
 	 * </pre>
-	 * 
+	 *
 	 * @see #thaw()
 	 */
 	public void freeze() {
 		checkState();
 		if (freezeList == null) {
 			freezeList = new LinkedList<ComponentChangeEvent>();
+			log.debug("Freezing Rocket");
+		} else {
+			ExceptionHandler.handleErrorCondition("Attempting to freeze Rocket when it is already frozen, " +
+					"freezeList=" + freezeList);
 		}
 	}
 	
@@ -453,13 +471,18 @@ public class Rocket extends RocketComponent {
 	 */
 	public void thaw() {
 		checkState();
-		if (freezeList == null)
+		if (freezeList == null) {
+			ExceptionHandler.handleErrorCondition("Attempting to thaw Rocket when it is not frozen");
 			return;
+		}
 		if (freezeList.size() == 0) {
+			log.warn("Thawing rocket with no changes made");
 			freezeList = null;
 			return;
 		}
 		
+		log.debug("Thawing rocket, freezeList=" + freezeList);
+		
 		int type = 0;
 		Object c = null;
 		for (ComponentChangeEvent e : freezeList) {
@@ -481,7 +504,7 @@ public class Rocket extends RocketComponent {
 	 * Return the default configuration.  This should be used in the user interface
 	 * to ensure a consistent rocket configuration between dialogs.  It should NOT
 	 * be used in simulations not relating to the UI.
-	 * 
+	 *
 	 * @return   the default {@link Configuration}.
 	 */
 	public Configuration getDefaultConfiguration() {
@@ -493,7 +516,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Return an array of the motor configuration IDs.  This array is guaranteed
 	 * to contain the <code>null</code> ID as the first element.
-	 * 
+	 *
 	 * @return  an array of the motor configuration IDs.
 	 */
 	public String[] getMotorConfigurationIDs() {
@@ -504,7 +527,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Add a new motor configuration ID to the motor configurations.  The new ID
 	 * is returned.
-	 * 
+	 *
 	 * @return  the new motor configuration ID.
 	 */
 	public String newMotorConfigurationID() {
@@ -517,7 +540,7 @@ public class Rocket extends RocketComponent {
 	
 	/**
 	 * Add a specified motor configuration ID to the motor configurations.
-	 * 
+	 *
 	 * @param id	the motor configuration ID.
 	 * @return		true if successful, false if the ID was already used.
 	 */
@@ -533,7 +556,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Remove a motor configuration ID from the configuration IDs.  The <code>null</code>
 	 * ID cannot be removed, and an attempt to remove it will be silently ignored.
-	 * 
+	 *
 	 * @param id   the motor configuration ID to remove
 	 */
 	public void removeMotorConfigurationID(String id) {
@@ -547,7 +570,7 @@ public class Rocket extends RocketComponent {
 	
 	/**
 	 * Check whether <code>id</code> is a valid motor configuration ID.
-	 * 
+	 *
 	 * @param id	the configuration ID.
 	 * @return		whether a motor configuration with that ID exists.
 	 */
@@ -560,7 +583,7 @@ public class Rocket extends RocketComponent {
 
 	/**
 	 * Check whether the given motor configuration ID has motors defined for it.
-	 * 
+	 *
 	 * @param id	the motor configuration ID (may be invalid).
 	 * @return		whether any motors are defined for it.
 	 */
@@ -569,7 +592,7 @@ public class Rocket extends RocketComponent {
 		if (id == null)
 			return false;
 		
-		Iterator<RocketComponent> iterator = this.deepIterator();
+		Iterator<RocketComponent> iterator = this.iterator();
 		while (iterator.hasNext()) {
 			RocketComponent c = iterator.next();
 			
@@ -589,7 +612,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Return the user-set name of the motor configuration.  If no name has been set,
 	 * returns an empty string (not null).
-	 *  
+	 *
 	 * @param id   the motor configuration id
 	 * @return	   the configuration name
 	 */
@@ -607,7 +630,7 @@ public class Rocket extends RocketComponent {
 	/**
 	 * Set the name of the motor configuration.  A name can be unset by passing
 	 * <code>null</code> or an empty string.
-	 * 
+	 *
 	 * @param id	the motor configuration id
 	 * @param name	the name for the motor configuration
 	 */
@@ -619,8 +642,8 @@ public class Rocket extends RocketComponent {
 	
 	
 	/**
-	 * Return either the motor configuration name (if set) or its description. 
-	 * 
+	 * Return either the motor configuration name (if set) or its description.
+	 *
 	 * @param id  the motor configuration ID.
 	 * @return    a textual representation of the configuration
 	 */
@@ -636,9 +659,9 @@ public class Rocket extends RocketComponent {
 	}
 	
 	/**
-	 * Return a description for the motor configuration, generated from the motor 
+	 * Return a description for the motor configuration, generated from the motor
 	 * designations of the components.
-	 * 
+	 *
 	 * @param id  the motor configuration ID.
 	 * @return    a textual representation of the configuration
 	 */
@@ -654,7 +677,7 @@ public class Rocket extends RocketComponent {
 		List<List<String>> list = new ArrayList<List<String>>();
 		List<String> currentList = null;
 		
-		Iterator<RocketComponent> iterator = this.deepIterator();
+		Iterator<RocketComponent> iterator = this.iterator();
 		while (iterator.hasNext()) {
 			RocketComponent c = iterator.next();
 			
@@ -681,10 +704,11 @@ public class Rocket extends RocketComponent {
 		}
 		
 		if (motorCount == 0) {
-			return "[No motors]";
+			//// [No motors]
+			return trans.get("Rocket.motorCount.Nomotor");
 		}
 		
-		// Change multiple occurrences of a motor to n x motor 
+		// Change multiple occurrences of a motor to n x motor
 		List<String> stages = new ArrayList<String>();
 		
 		for (List<String> stage : list) {
@@ -757,7 +781,8 @@ public class Rocket extends RocketComponent {
 
 	@Override
 	public String getComponentName() {
-		return "Rocket";
+		//// Rocket
+		return trans.get("Rocket.compname.Rocket");
 	}
 	
 	@Override
@@ -771,7 +796,7 @@ public class Rocket extends RocketComponent {
 	}
 	
 	@Override
-	public double getLongitudalUnitInertia() {
+	public double getLongitudinalUnitInertia() {
 		return 0;
 	}
 	
@@ -807,4 +832,5 @@ public class Rocket extends RocketComponent {
 	public boolean isCompatible(Class<? extends RocketComponent> type) {
 		return (Stage.class.isAssignableFrom(type));
 	}
+	
 }
