@@ -1,16 +1,18 @@
 package net.sf.openrocket.rocketcomponent;
 
 import static java.lang.Math.*;
-import static net.sf.openrocket.util.Chars.*;
 import static net.sf.openrocket.util.MathUtil.*;
 
 import java.util.Collection;
 
+import net.sf.openrocket.l10n.Translator;
+import net.sf.openrocket.startup.Application;
 import net.sf.openrocket.util.Coordinate;
 import net.sf.openrocket.util.MathUtil;
 
 
 public class Transition extends SymmetricComponent {
+	private static final Translator trans = Application.getTranslator();
 	private static final double CLIP_PRECISION = 0.0001;
 	
 
@@ -354,7 +356,7 @@ public class Transition extends SymmetricComponent {
 	/**
 	 * Numerically solve clipLength from the equation
 	 *     r1 == type.getRadius(clipLength,r2,clipLength+length)
-	 * using a binary search.  It assumes getRadius() to be monotonically increasing.
+	 * using a binary search.  It assumes getOuterRadius() to be monotonically increasing.
 	 */
 	private void calculateClip(double r1, double r2) {
 		double min = 0, max = length;
@@ -488,7 +490,8 @@ public class Transition extends SymmetricComponent {
 	 */
 	@Override
 	public String getComponentName() {
-		return "Transition";
+		//// Transition
+		return trans.get("Transition.Transition");
 	}
 	
 	@Override
@@ -497,17 +500,16 @@ public class Transition extends SymmetricComponent {
 		clipLength = -1;
 	}
 	
-	
 	/**
 	 * Check whether the given type can be added to this component.  Transitions allow any
 	 * InternalComponents to be added.
-	 * 
-	 * @param type  The RocketComponent class type to add.
+	 *
+	 * @param ctype  The RocketComponent class type to add.
 	 * @return      Whether such a component can be added.
 	 */
 	@Override
-	public boolean isCompatible(Class<? extends RocketComponent> type) {
-		if (InternalComponent.class.isAssignableFrom(type))
+	public boolean isCompatible(Class<? extends RocketComponent> ctype) {
+		if (InternalComponent.class.isAssignableFrom(ctype))
 			return true;
 		return false;
 	}
@@ -516,7 +518,7 @@ public class Transition extends SymmetricComponent {
 
 	/**
 	 * An enumeration listing the possible shapes of transitions.
-	 * 
+	 *
 	 * @author Sampo Niskanen <sampo.niskanen@iki.fi>
 	 */
 	public static enum Shape {
@@ -524,9 +526,12 @@ public class Transition extends SymmetricComponent {
 		/**
 		 * Conical shape.
 		 */
-		CONICAL("Conical",
-				"A conical nose cone has a profile of a triangle.",
-				"A conical transition has straight sides.") {
+		//// Conical
+		CONICAL(trans.get("Shape.Conical"),
+				//// A conical nose cone has a profile of a triangle.
+				trans.get("Shape.Conical.desc1"),
+				//// A conical transition has straight sides.
+				trans.get("Shape.Conical.desc2")) {
 			@Override
 			public double getRadius(double x, double radius, double length, double param) {
 				assert x >= 0;
@@ -541,15 +546,12 @@ public class Transition extends SymmetricComponent {
 		 * that will be used.  That is, for param==1 a tangent ogive will be produced, and
 		 * for smaller values the shape straightens out into a cone at param==0.
 		 */
-		OGIVE("Ogive",
-				"An ogive nose cone has a profile that is a segment of a circle.  " +
-						"The shape parameter value 1 produces a <b>tangent ogive</b>, which has " +
-						"a smooth transition to the body tube, values less than 1 produce " +
-						"<b>secant ogives</b>.",
-				"An ogive transition has a profile that is a segment of a circle.  " +
-						"The shape parameter value 1 produces a <b>tangent ogive</b>, which has " +
-						"a smooth transition to the body tube at the aft end, values less than 1 " +
-						"produce <b>secant ogives</b>.") {
+		//// Ogive
+		OGIVE(trans.get("Shape.Ogive"),
+				//// An ogive nose cone has a profile that is a segment of a circle.  The shape parameter value 1 produces a <b>tangent ogive</b>, which has a smooth transition to the body tube, values less than 1 produce <b>secant ogives</b>.
+				trans.get("Shape.Ogive.desc1"),
+				//// An ogive transition has a profile that is a segment of a circle.  	The shape parameter value 1 produces a <b>tangent ogive</b>, which has a smooth transition to the body tube at the aft end, values less than 1 produce <b>secant ogives</b>.
+				trans.get("Shape.Ogive.desc2")) {
 			@Override
 			public boolean usesParameter() {
 				return true; // Range 0...1 is default
@@ -591,13 +593,12 @@ public class Transition extends SymmetricComponent {
 		/**
 		 * Ellipsoidal shape.
 		 */
-		ELLIPSOID("Ellipsoid",
-				"An ellipsoidal nose cone has a profile of a half-ellipse " +
-						"with major axes of lengths 2&times;<i>Length</i> and <i>Diameter</i>.",
-				"An ellipsoidal transition has a profile of a half-ellipse " +
-						"with major axes of lengths 2&times;<i>Length</i> and <i>Diameter</i>.  If the " +
-						"transition is not clipped, then the profile is extended at the center by the " +
-						"corresponding radius.", true) {
+		//// Ellipsoid
+		ELLIPSOID(trans.get("Shape.Ellipsoid"),
+				//// An ellipsoidal nose cone has a profile of a half-ellipse with major axes of lengths 2&times;<i>Length</i> and <i>Diameter</i>.
+				trans.get("Shape.Ellipsoid.desc1"),
+				//// An ellipsoidal transition has a profile of a half-ellipse with major axes of lengths 2&times;<i>Length</i> and <i>Diameter</i>.  If the transition is not clipped, then the profile is extended at the center by the corresponding radius.		
+				trans.get("Shape.Ellipsoid.desc2"), true) {
 			@Override
 			public double getRadius(double x, double radius, double length, double param) {
 				assert x >= 0;
@@ -608,19 +609,10 @@ public class Transition extends SymmetricComponent {
 			}
 		},
 		
-		POWER("Power series",
-				"A power series nose cone has a profile of " +
-						"<i>Radius</i>&nbsp;&times;&nbsp;(<i>x</i>&nbsp;/&nbsp;<i>Length</i>)" +
-						"<sup><i>k</i></sup> " +
-						"where <i>k</i> is the shape parameter.  For <i>k</i>=0.5 this is a " +
-						"<b>" + FRAC12 + "-power</b> or <b>parabolic</b> nose cone, for <i>k</i>=0.75 a " +
-						"<b>" + FRAC34 + "-power</b>, and for <i>k</i>=1 a <b>conical</b> nose cone.",
-				"A power series transition has a profile of " +
-						"<i>Radius</i>&nbsp;&times;&nbsp;(<i>x</i>&nbsp;/&nbsp;<i>Length</i>)" +
-						"<sup><i>k</i></sup> " +
-						"where <i>k</i> is the shape parameter.  For <i>k</i>=0.5 the transition is " +
-						"<b>" + FRAC12 + "-power</b> or <b>parabolic</b>, for <i>k</i>=0.75 a " +
-						"<b>" + FRAC34 + "-power</b>, and for <i>k</i>=1 <b>conical</b>.", true) {
+		//// Power series
+		POWER(trans.get("Shape.Powerseries"),
+				trans.get("Shape.Powerseries.desc1"),
+				trans.get("Shape.Powerseries.desc2"), true) {
 			@Override
 			public boolean usesParameter() { // Range 0...1
 				return true;
@@ -649,17 +641,12 @@ public class Transition extends SymmetricComponent {
 			
 		},
 		
-		PARABOLIC("Parabolic series",
-				"A parabolic series nose cone has a profile of a parabola.  The shape " +
-						"parameter defines the segment of the parabola to utilize.  The shape " +
-						"parameter 1.0 produces a <b>full parabola</b> which is tangent to the body " +
-						"tube, 0.75 produces a <b>3/4 parabola</b>, 0.5 procudes a " +
-						"<b>1/2 parabola</b> and 0 produces a <b>conical</b> nose cone.",
-				"A parabolic series transition has a profile of a parabola.  The shape " +
-						"parameter defines the segment of the parabola to utilize.  The shape " +
-						"parameter 1.0 produces a <b>full parabola</b> which is tangent to the body " +
-						"tube at the aft end, 0.75 produces a <b>3/4 parabola</b>, 0.5 procudes a " +
-						"<b>1/2 parabola</b> and 0 produces a <b>conical</b> transition.") {
+		//// Parabolic series
+		PARABOLIC(trans.get("Shape.Parabolicseries"),
+				////A parabolic series nose cone has a profile of a parabola.  The shape parameter defines the segment of the parabola to utilize.  The shape parameter 1.0 produces a <b>full parabola</b> which is tangent to the body tube, 0.75 produces a <b>3/4 parabola</b>, 0.5 procudes a <b>1/2 parabola</b> and 0 produces a <b>conical</b> nose cone.
+				trans.get("Shape.Parabolicseries.desc1"),
+				////A parabolic series transition has a profile of a parabola.  The shape parameter defines the segment of the parabola to utilize.  The shape parameter 1.0 produces a <b>full parabola</b> which is tangent to the body tube at the aft end, 0.75 produces a <b>3/4 parabola</b>, 0.5 procudes a <b>1/2 parabola</b> and 0 produces a <b>conical</b> transition.
+				trans.get("Shape.Parabolicseries.desc2")) {
 			
 			// In principle a parabolic transition is clippable, but the difference is
 			// negligible.
@@ -686,18 +673,13 @@ public class Transition extends SymmetricComponent {
 			}
 		},
 		
-
-
-		HAACK("Haack series",
-				"The Haack series nose cones are designed to minimize drag.  The shape parameter " +
-						"0 produces an <b>LD-Haack</b> or <b>Von Karman</b> nose cone, which minimizes " +
-						"drag for fixed length and diameter, while a value of 0.333 produces an " +
-						"<b>LV-Haack</b> nose cone, which minimizes drag for fixed length and volume.",
-				"The Haack series <i>nose cones</i> are designed to minimize drag.  " +
-						"These transition shapes are their equivalents, but do not necessarily produce " +
-						"optimal drag for transitions.  " +
-						"The shape parameter 0 produces an <b>LD-Haack</b> or <b>Von Karman</b> shape, " +
-						"while a value of 0.333 produces an <b>LV-Haack</b> shape.", true) {
+		//// Haack series
+		HAACK(trans.get("Shape.Haackseries"),
+				//// The Haack series nose cones are designed to minimize drag.  The shape parameter 0 produces an <b>LD-Haack</b> or <b>Von Karman</b> nose cone, which minimizes drag for fixed length and diameter, while a value of 0.333 produces an <b>LV-Haack</b> nose cone, which minimizes drag for fixed length and volume.
+				trans.get("Shape.Haackseries.desc1"),
+				//// The Haack series <i>nose cones</i> are designed to minimize drag.  These transition shapes are their equivalents, but do not necessarily produce optimal drag for transitions.  The shape parameter 0 produces an <b>LD-Haack</b> or <b>Von Karman</b> shape, while a value of 0.333 produces an <b>LV-Haack</b> shape.		
+				trans.get("Shape.Haackseries.desc2"), true) {
+			
 			@Override
 			public boolean usesParameter() {
 				return true;
@@ -838,7 +820,7 @@ public class Transition extends SymmetricComponent {
 		 * shape parameter at the point x from the tip of the component.  It is assumed
 		 * that the fore radius if zero and the aft radius is <code>radius >= 0</code>.
 		 * Boattails are achieved by reversing the component.
-		 * 
+		 *
 		 * @param x      Position from the tip of the component.
 		 * @param radius Aft end radius >= 0.
 		 * @param length Length of the transition >= 0.
