@@ -6,6 +6,7 @@ import java.awt.event.ActionListener;
 import java.io.File;
 import java.io.PrintStream;
 import java.util.List;
+import java.util.Locale;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.swing.JOptionPane;
@@ -24,8 +25,11 @@ import net.sf.openrocket.file.motor.MotorLoaderHelper;
 import net.sf.openrocket.gui.dialogs.UpdateInfoDialog;
 import net.sf.openrocket.gui.main.BasicFrame;
 import net.sf.openrocket.gui.main.ExceptionHandler;
-import net.sf.openrocket.gui.main.SimpleFileFilter;
 import net.sf.openrocket.gui.main.Splash;
+import net.sf.openrocket.l10n.DebugTranslator;
+import net.sf.openrocket.l10n.L10N;
+import net.sf.openrocket.l10n.ResourceBundleTranslator;
+import net.sf.openrocket.l10n.Translator;
 import net.sf.openrocket.logging.DelegatorLogger;
 import net.sf.openrocket.logging.LogHelper;
 import net.sf.openrocket.logging.LogLevel;
@@ -35,6 +39,7 @@ import net.sf.openrocket.motor.Motor;
 import net.sf.openrocket.motor.ThrustCurveMotor;
 import net.sf.openrocket.util.GUIUtil;
 import net.sf.openrocket.util.Prefs;
+import net.sf.openrocket.util.SimpleFileFilter;
 
 
 /**
@@ -62,9 +67,15 @@ public class Startup {
 	
 	public static void main(final String[] args) throws Exception {
 		
+		// Check for "openrocket.debug" property before anything else
+		checkDebugStatus();
+		
 		// Initialize logging first so we can use it
 		initializeLogging();
 		
+		// Setup the translations
+		initializeL10n();
+		
 		// Check that we have a head
 		checkHead();
 		
@@ -91,6 +102,57 @@ public class Startup {
 	
 
 
+
+	private static void checkDebugStatus() {
+		if (System.getProperty("openrocket.debug") != null) {
+			setPropertyIfNotSet("openrocket.log.stdout", "VBOSE");
+			setPropertyIfNotSet("openrocket.log.tracelevel", "VBOSE");
+			setPropertyIfNotSet("openrocket.debug.menu", "true");
+			setPropertyIfNotSet("openrocket.debug.mutexlocation", "true");
+			setPropertyIfNotSet("openrocket.debug.motordigest", "true");
+		}
+	}
+	
+	private static void setPropertyIfNotSet(String key, String value) {
+		if (System.getProperty(key) == null) {
+			System.setProperty(key, value);
+		}
+	}
+	
+	
+	/**
+	 * Initializes the localization system.
+	 */
+	private static void initializeL10n() {
+		
+		String langcode = System.getProperty("openrocket.locale");
+		if (langcode != null) {
+			Locale l = L10N.toLocale(langcode);
+			log.info("Setting custom locale " + l);
+			Locale.setDefault(l);
+		} else {
+			Locale l = Prefs.getUserLocale();
+			if (l != null) {
+				log.info("Setting user-selected locale " + l);
+				Locale.setDefault(l);
+			} else {
+				log.info("Using default locale " + Locale.getDefault());
+			}
+		}
+		
+		Translator t;
+		t = new ResourceBundleTranslator("l10n.messages");
+		if (Locale.getDefault().getLanguage().equals("xx")) {
+			t = new DebugTranslator(t);
+		}
+		
+		log.info("Set up translation for locale " + Locale.getDefault() +
+				", debug.currentFile=" + t.get("debug.currentFile"));
+		
+		Application.setBaseTranslator(t);
+	}
+	
+	
 	private static void runMain(String[] args) {
 		
 		// Initialize the splash screen with version info
@@ -314,7 +376,7 @@ public class Startup {
 		// Check whether to log to stdout/stderr
 		PrintStreamLogger printer = new PrintStreamLogger();
 		boolean logout = setLogOutput(printer, System.out, System.getProperty(LOG_STDOUT_PROPERTY), null);
-		boolean logerr = setLogOutput(printer, System.err, System.getProperty(LOG_STDERR_PROPERTY), LogLevel.WARN);
+		boolean logerr = setLogOutput(printer, System.err, System.getProperty(LOG_STDERR_PROPERTY), LogLevel.ERROR);
 		if (logout || logerr) {
 			delegator.addLogger(printer);
 		}
